==> pymcfunction-0.1.1.tar.gz: pymcfunction-0.1.1/README.md <==
# PyFunction

PyMCFunction is a tool to write Minecraft datapacks in Python.

## Usage

Check pymcfunction/pyfunction/pmf --help

## Docs

Hopefully coming soon, for now, ask somthing like IntelliSense.

## Command support

These are the currently supported commands. Feel free to create a PR, the goal is to support every command.

 - [ ] /advancement
 - [ ] /attribute
 - [ ] /ban
 - [ ] /ban-ip
 - [ ] /banlist
 - [ ] /bossbar
 - [x] /clear
 - [ ] /clone
 - [ ] /data
 - [ ] /datapack
 - [ ] /debug
 - [x] /defaultgamemode
 - [x] /deop
 - [ ] /difficultiy
 - [ ] /effect
 - [ ] /enchant
 - [x] /execute
 - [ ] /experience (/xp)
 - [ ] /fill
 - [ ] /forceload
 - [x] /function
 - [ ] /gamemode
 - [ ] /gamerule
 - [ ] /give
 - [ ] /item
 - [ ] /kick
 - [ ] /kill
 - [ ] /locate
 - [ ] /loot
 - [ ] /msg (/tell and /w)
 - [ ] /op
 - [ ] /pardon
 - [ ] /pardon-ip
 - [ ] /particle
 - [ ] /place
 - [ ] /playsound
 - [ ] /publish
 - [ ] /recipe
 - [ ] /save-all
 - [ ] /save-off
 - [ ] /save-on
 - [x] /say
 - [ ] /schedule
 - [x] /scoreboard
 - [ ] /seed
 - [ ] /setblock
 - [ ] /setidletimeout
 - [ ] /setworldspawn
 - [ ] /spawnpoint
 - [ ] /spectate
 - [ ] /spreadplayers
 - [ ] /stop
 - [ ] /stopsound
 - [ ] /summon
 - [ ] /tag
 - [ ] /team
 - [ ] /teammsg (/tm)
 - [ ] /teleport (/tp)
 - [ ] /tellraw
 - [ ] /time
 - [ ] /title
 - [ ] /trigger
 - [ ] /weather
 - [ ] /whitelist
 - [ ] /worldborder

## Feedback

If you have any feedback, feature request, or think you know how a feature could be improved, feel free to open an issue.

==> pymcfunction-0.1.4.tar.gz: pymcfunction-0.1.4/README.md <==
# PyMCFunction

PyMCFunction is a tool to write Minecraft datapacks in Python.

## Usage

Check `pymcfunction/pyfunction/pmf --help`

## Docs

Hopefully coming soon, for now, ask somthing like IntelliSense.

## Command support

These are the currently supported commands. Feel free to create a PR, the goal is to support every command.

 - [ ] /advancement
 - [ ] /attribute
 - [x] /ban
 - [x] /ban-ip
 - [x] /banlist
 - [x] /bossbar
 - [x] /clear
 - [ ] /clone
 - [ ] /data
 - [ ] /datapack
 - [ ] /debug
 - [x] /defaultgamemode
 - [x] /deop
 - [x] /difficulty
 - [ ] /effect
 - [ ] /enchant
 - [x] /execute
 - [ ] /experience (/xp)
 - [ ] /fill
 - [ ] /forceload
 - [x] /function
 - [x] /gamemode
 - [x] /gamerule
 - [x] /give
 - [x] /item
 - [x] /kick
 - [x] /kill
 - [ ] /locate
 - [ ] /loot
 - [x] /op
 - [x] /pardon
 - [x] /pardon-ip
 - [ ] /particle
 - [ ] /place
 - [ ] /playsound
 - [ ] /publish
 - [ ] /recipe
 - [x] /save-all
 - [x] /save-off
 - [x] /save-on
 - [x] /say
 - [ ] /schedule
 - [x] /scoreboard
 - [x] /seed
 - [ ] /setblock
 - [x] /setidletimeout
 - [x] /setworldspawn
 - [x] /spawnpoint
 - [x] /spectate
 - [ ] /spreadplayers
 - [x] /stop
 - [x] /stopsound
 - [x] /summon
 - [x] /tag
 - [x] /team
 - [x] /teammsg (/tm)
 - [x] /teleport (/tp)
 - [ ] /tellraw
 - [ ] /time
 - [ ] /title
 - [ ] /trigger
 - [x] /weather
 - [ ] /whitelist
 - [ ] /worldborder

## Feedback

If you have any feedback, feature request, or think you know how a feature could be improved, feel free to open an issue.
